/*
 *  CellData.h
 *  GenomeMixerCPP
 */

#ifndef __GENOME_MIXER_CELL_DATA__
#define __GENOME_MIXER_CELL_DATA__

#include "PurebredData.h"
#include <iostream>
#include <stdlib.h>
#include <string>

class CellData {
    private:
        bool myCommentedOut;
	bool myToBeExported;
	bool myValid;
	
	int myRandomAssignSex; // number of progeny for which the sex is determined randomly
	int myMinFemales;
	int myMinMales;		
	int myMotherGen;
	int myMotherCage;	
	int myFatherGen;
	int myFatherCage;       	
	int myMotherPurebredIndex;	
	int myFatherPurebredIndex;	
	
    public:
	CellData::CellData(bool comment, bool toExport, int rand, int fem, int male);
	CellData::CellData(CellData* other); // copy-ish constructor
	CellData::CellData(void);	     // constructor
        
	void CellData::overwriteWithDataFrom(CellData* other); // copies the data from "other" into this CellData

	string CellData::toString(PurebredData *pure);
	string CellData::motherString(PurebredData *pure);
	string CellData::fatherString(PurebredData *pure);
	
	void   CellData::setCommentedOut(bool newValue);
	void   CellData::setToBeExported(bool newValue);

	bool CellData::commentedOut(void);
	bool CellData::toBeExported(void);

	void CellData::setRandomSex(int numRandom);
	int  CellData::randomSex(void);	
	
	int  CellData::minFemales(void);
	int  CellData::minMales(void);
	void CellData::setMinFemales(int newMinFemales);
	void CellData::setMinMales(int newMinMales);
	void CellData::setMother(int cageIndex, int genIndex);
	void CellData::setFather(int cageIndex, int genIndex);
	void CellData::setMotherPurebred(int pureIndexFem);
	void CellData::setFatherPurebred(int pureIndexMale);
	
	int CellData::motherCage(void);
	int CellData::motherGen(void);
	int CellData::fatherCage(void);
	int CellData::fatherGen(void);
	
	bool CellData::motherIsPurebred(void);
	bool CellData::fatherIsPurebred(void);
	
	int CellData::motherPurebredIndex(void);
	int CellData::fatherPurebredIndex(void);
	
};  // <-- remember the semicolon at the end of the class definition!

#endif

